import React, { useState, useEffect, useRef } from "react";

interface DropdownProps {
  header: string;
  options: string[];
  onSelect: (option: string) => void;
}

const RegularDropDown: React.FC<DropdownProps> = ({
  header,
  options,
  onSelect,
}) => {
  const [isOpen, setIsOpen] = useState(false);
  const [selectedOption, setSelectedOption] = useState<string | null>(null);
  const dropdownRef = useRef<HTMLDivElement>(null); // Create a ref for the dropdown container

  // Reset selectedOption when the dropdown closes
  useEffect(() => {
    if (!isOpen) {
      setSelectedOption(null); // Clear local state when the dropdown closes
    }
  }, [isOpen]);

  // Reset selectedOption when the header prop changes
  useEffect(() => {
    setSelectedOption(null); // Ensure the dropdown reflects the updated header
  }, [header]);

  // Close dropdown if clicked outside
  useEffect(() => {
    const handleClickOutside = (event: MouseEvent) => {
      if (dropdownRef.current && !dropdownRef.current.contains(event.target as Node)) {
        setIsOpen(false); // Close the dropdown if clicked outside
      }
    };

    document.addEventListener("click", handleClickOutside);

    // Cleanup the event listener on component unmount
    return () => {
      document.removeEventListener("click", handleClickOutside);
    };
  }, []);

  const toggleDropdown = () => {
    setIsOpen((prev) => !prev);
  };

  const handleOptionClick = (option: string) => {
    setSelectedOption(option);
    onSelect(option); // Call the onSelect function passed from the parent
    setIsOpen(false); // Close the dropdown after selection
  };

  return (
    <div className="regularDropdown-container" ref={dropdownRef}>
      {/* Dropdown Header */}
      <div className="dropdown-header flex-sb" onClick={toggleDropdown}>
        <div className="key">{selectedOption || header}</div>
        <div className="icon">▾</div>
      </div>

      {/* Dropdown Options */}
      {isOpen && (
        <div className="dropdown-options">
          {options.map((option, index) => (
            <div
              className="option"
              key={index}
              onClick={() => handleOptionClick(option)}
            >
              {option}
            </div>
          ))}
        </div>
      )}
    </div>
  );
};

export default RegularDropDown;
